@@ -27,32 +27,25 @@ def getWorkDir(dataset, dataBuild):
     return workdir
 
 
-RELATE_DATA = Namespace ("http://generalbioinformatics.com/data/relate#")
-RELATE_VOC = Namespace ("http://generalbioinformatics.com/ontologies/relate#")
 
+# Public dataset graphs
 CHEMBL_DATA = Namespace ("http://generalbioinformatics.com/data/chembl#")
 CHEMBL_VOC = Namespace ("http://generalbioinformatics.com/ontologies/chembl#")
 
-PROJECT_DATA = Namespace ("http://generalbioinformatics.com/data/project#")
-PROJECT_VOC = Namespace ("http://generalbioinformatics.com/ontologies/project#")
 
-PHENOTYPE_DATA = Namespace ("http://generalbioinformatics.com/data/phenotype#")
-PHENOTYPE_VOC = Namespace ("http://generalbioinformatics.com/ontologies/phenotype#")
+# Internal dataset graphs
+CSIM_VOC = Namespace("http://generalbioinformatics.com/ontologies/crossSystemIdMapping#")
+CSIM_DATA = Namespace("http://generalbioinformatics.com/data/crossSystemIdMapping#")
 
 MAP_DATA = Namespace ("http://generalbioinformatics.com/data/idMapping#")
 MAP_VOC = Namespace ("http://generalbioinformatics.com/ontologies/idMapping#")
 
-def getCompoundUri(cid):
-        """
-                STITCH has two kinds of compounds ids
-                Some are labelled stereochemical ids. They start with CID0... 
-                 and are actually pubchem compound (not substance!) ids with CID, a zero, and more digits (nine in total).
-                The others are flat ids, and start with CID, a one, and more digits (also nine in total).
-                These do not seem to have a correspondence with PubChem.
-        """
-        cidPat = "^CID0*"
-        if not (re.match (cidPat, cid)):
-                raise Exception("" + cid + " doesn't match pattern CID\d+")
-        cid = re.sub (cidPat, '', cid)
-        return idPubchemCompound[cid]
+PHENOTYPE_DATA = Namespace ("http://generalbioinformatics.com/data/phenotype#")
+PHENOTYPE_VOC = Namespace ("http://generalbioinformatics.com/ontologies/phenotype#")
+
+PROJECT_DATA = Namespace ("http://generalbioinformatics.com/data/project#")
+PROJECT_VOC = Namespace ("http://generalbioinformatics.com/ontologies/project#")
+
+RELATE_DATA = Namespace ("http://generalbioinformatics.com/data/relate#")
+RELATE_VOC = Namespace ("http://generalbioinformatics.com/ontologies/relate#")
 
